@@ -3,10 +3,7 @@ from copy import deepcopy
 from typing import Dict, List, Optional, Set, Tuple
 
 from .utilities.reader import Read
-from .utilities.sources import (
-    get_hxltag_source_date,
-    standardise_datasetinfo_source_date,
-)
+from .utilities.sources import Sources
 
 
 class BaseScraper(ABC):
@@ -144,13 +141,13 @@ class BaseScraper(ABC):
         source_url = self.datasetinfo["source_url"]
         if isinstance(source_url, str):
             source_url = {"default_url": source_url}
-        standardise_datasetinfo_source_date(self.datasetinfo)
+        Sources.standardise_datasetinfo_source_date(self.datasetinfo)
         if self.source_configuration is None:
             for level in self.headers:
                 self.sources[level] = [
                     (
                         hxltag,
-                        get_hxltag_source_date(
+                        Sources.get_hxltag_source_date(
                             self.datasetinfo, hxltag, fallback=True
                         ),
                         source.get(hxltag, source["default_source"]),
@@ -165,15 +162,15 @@ class BaseScraper(ABC):
             def add_source(hxltag, suffix_attribute):
                 hxltag_suffix = f"{hxltag}+{suffix_attribute.lower()}"
                 source_suffix = f"CUSTOM_{suffix_attribute}"
-                out_date = get_hxltag_source_date(
+                out_date = Sources.get_hxltag_source_date(
                     self.datasetinfo, hxltag_suffix
                 )
                 if not out_date:
-                    out_date = get_hxltag_source_date(
+                    out_date = Sources.get_hxltag_source_date(
                         self.datasetinfo, source_suffix
                     )
                 if not out_date:
-                    out_date = get_hxltag_source_date(
+                    out_date = Sources.get_hxltag_source_date(
                         self.datasetinfo, hxltag, fallback=True
                     )
                 out_source = source.get(hxltag_suffix)
@@ -244,7 +241,7 @@ class BaseScraper(ABC):
         Returns:
             None
         """
-        date = get_hxltag_source_date(
+        date = Sources.get_hxltag_source_date(
             self.datasetinfo, indicator, fallback=True
         )
         self.sources[key] = [
